@@ -149,6 +149,7 @@ def find_and_parse(
     if not isinstance(parsed_files, list):
         parsed_files = [parsed_files]
 
+    parsed_files = [f for f in parsed_files if f is not None]
     return parsed_files
 
 
@@ -351,7 +352,7 @@ def import_annotations(
         raise ValueError("Not able to parse any files.")
 
     parsed_files = list(maybe_parsed_files)
-    filenames: List[str] = [parsed_file.filename for parsed_file in parsed_files]
+    filenames: List[str] = [parsed_file.filename for parsed_file in parsed_files if parsed_file is not None]
 
     console.print("Fetching remote file list...", style="info")
     # This call will only filter by filename; so can return a superset of matched files across different paths
